Apple.DeviceCheckAPI (apple v0.6.0)

Copy Markdown View Source

Utilities for DeviceCheck API.

DeviceCheck allows you to validate device tokens and query/update device state bits to detect fraudulent activity on iOS, tvOS, and macOS devices.

Summary

Functions

Builds a token to authorize DeviceCheck HTTP requests.

Returns the DeviceCheck API base URL for development.

Returns the DeviceCheck API base URL for production.

Functions

build_auth_token!(issuer_id, key_id, private_key)

Builds a token to authorize DeviceCheck HTTP requests.

After building it, use it in the Authorization header like this:

Authorization: Bearer <JWT>

More resources

development_url()

@spec development_url() :: String.t()

Returns the DeviceCheck API base URL for development.

production_url()

@spec production_url() :: String.t()

Returns the DeviceCheck API base URL for production.