Apple.GameCenterAPI (apple v0.6.0)

Copy Markdown View Source

Utilities for Game Center API.

The Game Center API allows server-side access to leaderboards, achievements, and player data for games using Game Center.

Summary

Functions

Returns the Game Center API base URL.

Builds a token to authorize Game Center API requests.

Functions

base_url()

@spec base_url() :: String.t()

Returns the Game Center API base URL.

build_auth_token!(team_id, key_id, private_key, bundle_id)

Builds a token to authorize Game Center API requests.

After building it, use it in the Authorization header like this:

Authorization: Bearer <JWT>

More resources