Apple.Types.DeviceCheck (apple v0.6.0)

Copy Markdown View Source

Provides DeviceCheck API related types.

Summary

Types

Bit state for DeviceCheck (0 or 1 for each of two bits).

The device token received from the device, base64-encoded.

The issuer ID (Team ID), which is a 10-character string, like "6MPDV0UYYX"

The private key ID for DeviceCheck, like "2Y9R5HMY68".

The private key associated with the key_id.

The timestamp for the request in milliseconds since 1970.

The transaction ID (UUID) for tracking requests.

Types

bit_state()

@type bit_state() :: 0 | 1

Bit state for DeviceCheck (0 or 1 for each of two bits).

device_token()

@type device_token() :: String.t()

The device token received from the device, base64-encoded.

issuer_id()

@type issuer_id() :: String.t()

The issuer ID (Team ID), which is a 10-character string, like "6MPDV0UYYX"

To obtain the team ID, sign into Apple Developer and complete the following steps:

  1. Navigate to "Membership details".

key_id()

@type key_id() :: String.t()

The private key ID for DeviceCheck, like "2Y9R5HMY68".

To obtain the private key ID, sign into Apple Developer and complete the following steps:

  1. Navigate to "Certificates, IDs & Profiles".
  2. Navigate to "Keys".
  3. Generate a new key with DeviceCheck enabled.
  4. Download the private key.

private_key()

@type private_key() :: String.t()

The private key associated with the key_id.

It's in PEM format, like:

-----BEGIN PRIVATE KEY-----
xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
...
-----END PRIVATE KEY-----

timestamp()

@type timestamp() :: integer()

The timestamp for the request in milliseconds since 1970.

transaction_id()

@type transaction_id() :: String.t()

The transaction ID (UUID) for tracking requests.