Apple.Types.GameCenter (apple v0.6.0)

Copy Markdown View Source

Provides Game Center API related types.

Summary

Types

An achievement ID.

The app's bundle ID, like "com.example.game".

The private key ID for Game Center API, like "2Y9R5HMY68".

A leaderboard ID.

A player ID in Game Center.

The private key associated with the key_id.

The issuer ID (Team ID), which is a 10-character string, like "6MPDV0UYYX"

Types

achievement_id()

@type achievement_id() :: String.t()

An achievement ID.

bundle_id()

@type bundle_id() :: String.t()

The app's bundle ID, like "com.example.game".

key_id()

@type key_id() :: String.t()

The private key ID for Game Center API, like "2Y9R5HMY68".

To obtain the private key ID, sign into Apple Developer and complete the following steps:

  1. Navigate to "Certificates, IDs & Profiles".
  2. Navigate to "Keys".
  3. Generate a new key with Game Center enabled.
  4. Download the private key.

leaderboard_id()

@type leaderboard_id() :: String.t()

A leaderboard ID.

player_id()

@type player_id() :: String.t()

A player ID in Game Center.

private_key()

@type private_key() :: String.t()

The private key associated with the key_id.

It's in PEM format, like:

-----BEGIN PRIVATE KEY-----
xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
...
-----END PRIVATE KEY-----

team_id()

@type team_id() :: String.t()

The issuer ID (Team ID), which is a 10-character string, like "6MPDV0UYYX"

To obtain the team ID, sign into Apple Developer and complete the following steps:

  1. Navigate to "Membership details".