Utilities for DeviceCheck API.
DeviceCheck allows you to validate device tokens and query/update device state bits to detect fraudulent activity on iOS, tvOS, and macOS devices.
Summary
Functions
Builds a token to authorize DeviceCheck HTTP requests.
Returns the DeviceCheck API base URL for development.
Returns the DeviceCheck API base URL for production.
Functions
@spec build_auth_token!( Apple.Types.DeviceCheck.issuer_id(), Apple.Types.DeviceCheck.key_id(), Apple.Types.DeviceCheck.private_key() ) :: String.t()
Builds a token to authorize DeviceCheck HTTP requests.
After building it, use it in the Authorization header like this:
Authorization: Bearer <JWT>More resources
@spec development_url() :: String.t()
Returns the DeviceCheck API base URL for development.
@spec production_url() :: String.t()
Returns the DeviceCheck API base URL for production.