Utilities for Game Center API.
The Game Center API allows server-side access to leaderboards, achievements, and player data for games using Game Center.
Summary
Functions
Returns the Game Center API base URL.
Builds a token to authorize Game Center API requests.
Functions
@spec base_url() :: String.t()
Returns the Game Center API base URL.
@spec build_auth_token!( Apple.Types.GameCenter.team_id(), Apple.Types.GameCenter.key_id(), Apple.Types.GameCenter.private_key(), Apple.Types.GameCenter.bundle_id() ) :: String.t()
Builds a token to authorize Game Center API requests.
After building it, use it in the Authorization header like this:
Authorization: Bearer <JWT>